==> google-ads-21.2.0.tar.gz: google-ads-21.2.0/google/ads/googleads/v14/resources/types/ad_group_extension_setting.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableSequence

import proto  # type: ignore

from google.ads.googleads.v14.enums.types import extension_setting_device
from google.ads.googleads.v14.enums.types import (
    extension_type as gage_extension_type,
)


__protobuf__ = proto.module(
    package="google.ads.googleads.v14.resources",
    marshal="google.ads.googleads.v14",
    manifest={"AdGroupExtensionSetting",},
)


class AdGroupExtensionSetting(proto.Message):
    r"""An ad group extension setting.
    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        resource_name (str):
            Immutable. The resource name of the ad group extension
            setting. AdGroupExtensionSetting resource names have the
            form:

            ``customers/{customer_id}/adGroupExtensionSettings/{ad_group_id}~{extension_type}``
        extension_type (google.ads.googleads.v14.enums.types.ExtensionTypeEnum.ExtensionType):
            Immutable. The extension type of the ad group
            extension setting.
        ad_group (str):
            Immutable. The resource name of the ad group. The linked
            extension feed items will serve under this ad group. AdGroup
            resource names have the form:

            ``customers/{customer_id}/adGroups/{ad_group_id}``

            This field is a member of `oneof`_ ``_ad_group``.
        extension_feed_items (MutableSequence[str]):
            The resource names of the extension feed items to serve
            under the ad group. ExtensionFeedItem resource names have
            the form:

            ``customers/{customer_id}/extensionFeedItems/{feed_item_id}``
        device (google.ads.googleads.v14.enums.types.ExtensionSettingDeviceEnum.ExtensionSettingDevice):
            The device for which the extensions will
            serve. Optional.
    """

    resource_name: str = proto.Field(
        proto.STRING, number=1,
    )
    extension_type: gage_extension_type.ExtensionTypeEnum.ExtensionType = proto.Field(
        proto.ENUM,
        number=2,
        enum=gage_extension_type.ExtensionTypeEnum.ExtensionType,
    )
    ad_group: str = proto.Field(
        proto.STRING, number=6, optional=True,
    )
    extension_feed_items: MutableSequence[str] = proto.RepeatedField(
        proto.STRING, number=7,
    )
    device: extension_setting_device.ExtensionSettingDeviceEnum.ExtensionSettingDevice = proto.Field(
        proto.ENUM,
        number=5,
        enum=extension_setting_device.ExtensionSettingDeviceEnum.ExtensionSettingDevice,
    )


__all__ = tuple(sorted(__protobuf__.manifest))

==> google-ads-22.1.0.tar.gz: google-ads-22.1.0/google/ads/googleads/v14/resources/types/ad_group_extension_setting.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableSequence

import proto  # type: ignore

from google.ads.googleads.v14.enums.types import extension_setting_device
from google.ads.googleads.v14.enums.types import (
    extension_type as gage_extension_type,
)


__protobuf__ = proto.module(
    package="google.ads.googleads.v14.resources",
    marshal="google.ads.googleads.v14",
    manifest={
        "AdGroupExtensionSetting",
    },
)


class AdGroupExtensionSetting(proto.Message):
    r"""An ad group extension setting.
    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        resource_name (str):
            Immutable. The resource name of the ad group extension
            setting. AdGroupExtensionSetting resource names have the
            form:

            ``customers/{customer_id}/adGroupExtensionSettings/{ad_group_id}~{extension_type}``
        extension_type (google.ads.googleads.v14.enums.types.ExtensionTypeEnum.ExtensionType):
            Immutable. The extension type of the ad group
            extension setting.
        ad_group (str):
            Immutable. The resource name of the ad group. The linked
            extension feed items will serve under this ad group. AdGroup
            resource names have the form:

            ``customers/{customer_id}/adGroups/{ad_group_id}``

            This field is a member of `oneof`_ ``_ad_group``.
        extension_feed_items (MutableSequence[str]):
            The resource names of the extension feed items to serve
            under the ad group. ExtensionFeedItem resource names have
            the form:

            ``customers/{customer_id}/extensionFeedItems/{feed_item_id}``
        device (google.ads.googleads.v14.enums.types.ExtensionSettingDeviceEnum.ExtensionSettingDevice):
            The device for which the extensions will
            serve. Optional.
    """

    resource_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    extension_type: gage_extension_type.ExtensionTypeEnum.ExtensionType = (
        proto.Field(
            proto.ENUM,
            number=2,
            enum=gage_extension_type.ExtensionTypeEnum.ExtensionType,
        )
    )
    ad_group: str = proto.Field(
        proto.STRING,
        number=6,
        optional=True,
    )
    extension_feed_items: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=7,
    )
    device: extension_setting_device.ExtensionSettingDeviceEnum.ExtensionSettingDevice = proto.Field(
        proto.ENUM,
        number=5,
        enum=extension_setting_device.ExtensionSettingDeviceEnum.ExtensionSettingDevice,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
